EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Packages_RecordPackageDeployment',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'PackageDeployment_Id',
    /* Description_Text        */ 'Records a package deployment by an external program.'
GO

IF OBJECT_ID('[Packages_RecordPackageDeployment]') IS NOT NULL DROP PROCEDURE [Packages_RecordPackageDeployment]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Packages_RecordPackageDeployment]
(
	@Feed_Id INT,
    @Package_Name NVARCHAR(200),
    @Group_Name NVARCHAR(200),
    @Version_Text NVARCHAR(100),
    @Application_Name VARCHAR(255),
    @Url_Text NVARCHAR(255),
    @DeploymentTarget_Name NVARCHAR(255),
    @Deployment_Date DATETIME,
    @DeployedBy_User_Name USERNAME,
    @Description_Text NVARCHAR(MAX),
    @PackageDeployment_Id INT = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    INSERT INTO [PackageDeployments]
    (
         [Feed_Id]
        ,[Package_Name] 
        ,[Group_Name] 
        ,[Version_Text] 
        ,[Application_Name]
        ,[Url_Text]
        ,[DeploymentTarget_Name]
        ,[Deployment_Date]
        ,[DeployedBy_User_Name]
        ,[Description_Text]
    )
    VALUES
    (
         @Feed_Id
        ,@Package_Name
        ,NULLIF(@Group_Name, '')
        ,@Version_Text
        ,@Application_Name
        ,@Url_Text
        ,@DeploymentTarget_Name
        ,@Deployment_Date
        ,@DeployedBy_User_Name
        ,@Description_Text
    )

    SET @PackageDeployment_Id = SCOPE_IDENTITY()

    COMMIT

END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Packages_RecordPackageDeployment] TO [ProGetUser_Role]
GO